@@ -8,6 +8,7 @@ import base64
 import atexit
 import signal
 import traceback
+import suanpan
 from suanpan.g import g
 from suanpan.log import logger
 from suanpan.base import Context
@@ -80,6 +81,7 @@ class APP:
         return self
 
     def start(self, *args, **kwargs):
+        logger.info(f"Start Suanpan SDK: {suanpan.__version__}...")
         logger.info("Start Running...")
         try:
             self.paramContext = self.loadParams(g)
@@ -196,5 +198,8 @@ class APP:
         self.outputArgs.update({args.key: args})
         return self
 
+    def close(self):
+        stream.close()
+
 
 app = APP()
